@@ -19,7 +19,7 @@ use Encode qw(encode decode);
 use Carp qw(carp croak );
 
 use vars qw'$VERSION %link_spec';
-$VERSION = '0.44';
+$VERSION = '0.45';
 
 =head1 NAME
 
@@ -397,6 +397,9 @@ JS
     };
 JS
     $window ||= $self->tab->{linkedBrowser}->{contentWindow};
+    # Report errors from scope of caller
+    local @MozRepl::RemoteObject::Instance::CARP_NOT = (@MozRepl::RemoteObject::Instance::CARP_NOT,__PACKAGE__);
+    #warn Dumper @MozRepl::RemoteObject::CARP_NOT;
     return $eval_in_sandbox->($window,$doc,$str,$js_env);
 };
 *eval = \&eval_in_page;
@@ -1868,6 +1871,7 @@ C<< any >> - no error is raised, no matter if an item is found or not.
 Returns the matched nodes.
 
 You can pass in a list of queries as an array reference for the first parameter.
+The result will then be the list of all elements matching any of the queries.
 
 This is a method that is not implemented in WWW::Mechanize.
 
@@ -1887,7 +1891,6 @@ sub xpath {
         #warn "Have node, searching below node";
     } else {
         $options{ document } ||= $self->document;
-        #$options{ node } = $options{ document };
     };
     
     $options{ user_info } ||= join " or ", map {qq{'$_'}} @$query;
@@ -1969,7 +1972,7 @@ sub xpath {
   my @text = $mech->selector('p.content');
 
 Returns all nodes matching the given CSS selector. If
-$css_selector is an array reference, it returns
+C<$css_selector> is an array reference, it returns
 all nodes matched by any of the CSS selectors in the array.
 
 This takes the same options that C<< ->xpath >> does.
@@ -1989,6 +1992,35 @@ sub selector {
     $self->xpath(\@q, %options);
 };
 
+=head2 C<< $mech->by_id $id, %options >>
+
+  my @text = $mech->by_id('_foo:bar');
+
+Returns all nodes matching the given ids. If
+C<$id> is an array reference, it returns
+all nodes matched by any of the ids in the array.
+
+This method is equivalent to calling C<< ->xpath >> :
+
+    $self->xpath(qq{//*[\@id="$_"], %options)
+
+It is convenient when your element ids get mistaken for
+CSS selectors.
+
+=cut
+
+sub by_id {
+    my ($self,$query,%options) = @_;
+    if ('ARRAY' ne (ref $query||'')) {
+        $query = [$query];
+    };
+    $options{ user_info } ||= "id " 
+                            . join(" or ", map {qq{'$_'}} @$query)
+                            . " found";
+    $query = [map { qq{.//*[\@id="$_"]} } @$query];
+    $self->xpath($query, %options)
+}
+
 =head2 C<< $mech->click $name [,$x ,$y] >>
 
   $mech->click( 'go' );
@@ -2020,6 +2052,15 @@ C<dom> - Click on the passed DOM element
 
 =item *
 
+C<id> - Click on the element with the given id
+
+This is useful if your document ids contain characters that
+do look like CSS selectors. It is equivalent to
+
+    xpath => qq{//*[\@id="$id"}
+
+=item *
+
 C<synchronize> - Synchronize the click (default is 1)
 
 Synchronizing means that WWW::Mechanize::Firefox will wait until
@@ -2150,7 +2191,7 @@ are identical to those accepted by the L</$mech->xpath> method.
 
 This is equivalent to calling
 
-    $mech->selector("#$id",single => 1,%options)
+    $mech->by_id($id,single => 1,%options)
 
 =cut
 
@@ -2158,8 +2199,8 @@ sub form_id {
     my ($self,$name,%options) = @_;
     
     _default_limiter( single => \%options );
-    $self->{current_form} = $self->selector("#$name",
-        user_info => "form id '$name'",
+    $self->{current_form} = $self->by_id($name,
+        user_info => "form with id '$name'",
         %options
     );
 };
@@ -2339,11 +2380,10 @@ sub _field_by_name {
         @fields = $name;
     } else {
         _default_limiter( single => \%options );
-        @fields = $self->xpath(
+        my $query = 
             sprintf( q{.//input[@%s="%s"] | .//select[@%s="%s"] | .//textarea[@%s="%s"]}, 
-                               $attr,$name,          $attr,$name,          $attr,$name ),
-            %options,
-        );
+                               $attr,$name,          $attr,$name,          $attr,$name );
+        @fields = $self->xpath($query,%options);
     };
     @fields
 }
@@ -2893,15 +2933,22 @@ sub wait_until_invisible {
     };    
 };
 
-# Internal method to run either an XPath or CSS query against the DOM
+# Internal method to run either an XPath, CSS or id query against the DOM
 # Returns the element(s) found
+my %rename = (
+    xpath => 'xpath',
+    selector => 'selector',
+    id => 'by_id',
+    by_id => 'by_id',
+);
+
 sub _option_query {
     my ($self,%options) = @_;
     my ($method,$q);
-    for my $meth (qw(selector xpath)) {
+    for my $meth (keys %rename) {
         if (exists $options{ $meth }) {
             $q = delete $options{ $meth };
-            $method = $meth;
+            $method = $rename{ $meth } || $meth;
         }
     };
     _default_limiter( 'one' => \%options );
